@@ -44,6 +44,12 @@ void Archive::UnexpEndArcMsg()
 
 size_t Archive::ReadHeader()
 {
+  // Once we failed to decrypt an encrypted block, there is no reason to
+  // attempt to do it further. We'll never be successful and only generate
+  // endless errors.
+  if (FailedHeaderDecryption)
+    return 0;
+
   CurBlockPos=Tell();
 
 #ifndef SFX_MODULE
@@ -185,7 +191,7 @@ size_t Archive::ReadHeader()
         hd->FullUnpSize=INT32TO64(hd->HighUnpSize,hd->UnpSize);
 
         char FileName[NM*4];
-        int NameSize=Min(hd->NameSize,sizeof(FileName)-1);
+        size_t NameSize=Min(hd->NameSize,sizeof(FileName)-1);
         Raw.Get((byte *)FileName,NameSize);
         FileName[NameSize]=0;
 
@@ -426,12 +432,12 @@ size_t Archive::ReadHeader()
 #ifndef SILENT
         Log(FileName,St(MEncrBadCRC),FileName);
 #endif
-        Close();
-
+//        Close();
+        FailedHeaderDecryption=true;
         BrokenFileHeader=true;
+
         ErrHandler.SetErrorCode(CRC_ERROR);
         return(0);
-//        ErrHandler.Exit(CRC_ERROR);
       }
     }
   }
@@ -573,13 +579,15 @@ void Archive::ConvertAttributes()
 #endif
 #ifdef _UNIX
   // umask defines which permission bits must not be set by default
-  // when creating a file or directory.
+  // when creating a file or directory. The typical default value
+  // for the process umask is S_IWGRP | S_IWOTH (octal 022),
+  // resulting in 0644 mode for new files.
   static mode_t mask = (mode_t) -1;
 
   if (mask == (mode_t) -1)
   {
     // umask call returns the current umask value. Argument (022) is not 
-    // important here.
+    // really important here.
     mask = umask(022);
 
     // Restore the original umask value, which was changed to 022 above.
