@@ -114,9 +114,9 @@ EXTRACT_ARC_CODE CmdExtract::ExtractArchive(CommandData *Cmd)
     return(EXTRACT_ARC_NEXT);
   }
 
-  // archive with corrupt encrypted header can be closed in IsArchive() call
-  if (!Arc.IsOpened())
-    return(EXTRACT_ARC_NEXT);
+  // Archive with corrupt encrypted header can be closed in IsArchive() call.
+//  if (!Arc.IsOpened())
+//    return(EXTRACT_ARC_NEXT);
 
 #ifndef SFX_MODULE
   if (Arc.Volume && Arc.NotFirstVolume)
@@ -179,8 +179,8 @@ EXTRACT_ARC_CODE CmdExtract::ExtractArchive(CommandData *Cmd)
   Arc.ViewComment();
 
   // RAR can close a corrupt encrypted archive
-  if (!Arc.IsOpened())
-    return(EXTRACT_ARC_NEXT);
+//  if (!Arc.IsOpened())
+//    return(EXTRACT_ARC_NEXT);
 
 
   while (1)
@@ -709,6 +709,7 @@ bool CmdExtract::ExtractCurrentFile(CommandData *Cmd,Archive &Arc,size_t HeaderS
           else
           {
             Log(Arc.FileName,St(MExtrErrMkDir),DestFileName);
+            ErrHandler.CheckLongPathErrMsg(DestFileName,DestNameW);
             ErrHandler.SysErrMsg();
 #ifdef RARDLL
             Cmd->DllError=ERAR_ECREATE;
@@ -870,7 +871,7 @@ bool CmdExtract::ExtractCurrentFile(CommandData *Cmd,Archive &Arc,size_t HeaderS
               Unp->DoUnpack(Arc.NewLhd.UnpVer,(Arc.NewLhd.Flags & LHD_SOLID)!=0);
           }
 
-      if (Arc.IsOpened())
+//      if (Arc.IsOpened())
         Arc.SeekToNext();
 
       bool ValidCRC=Arc.OldFormat && UINT32(DataIO.UnpFileCRC)==UINT32(Arc.NewLhd.FileCRC) ||
@@ -952,7 +953,7 @@ bool CmdExtract::ExtractCurrentFile(CommandData *Cmd,Archive &Arc,size_t HeaderS
   }
   if (ExactMatch)
     MatchedArgs++;
-  if (DataIO.NextVolumeMissing || !Arc.IsOpened())
+  if (DataIO.NextVolumeMissing/* || !Arc.IsOpened()*/)
     return(false);
   if (!ExtrFile)
     if (!Arc.Solid)
