@@ -4,10 +4,10 @@
 bool FileCreate(RAROptions *Cmd,File *NewFile,char *Name,wchar *NameW,
                 OVERWRITE_MODE Mode,bool *UserReject,int64 FileSize=INT64NDF,
                 uint FileTime=0);
-bool GetAutoRenamedName(char *Name);
+bool GetAutoRenamedName(char *Name,wchar *NameW);
 
-#if defined(_WIN_32) && !defined(_WIN_CE)
-bool UpdateExistingShortName(char *Name,wchar *NameW);
+#if defined(_WIN_ALL) && !defined(_WIN_CE)
+bool UpdateExistingShortName(wchar *Name);
 #endif
 
 #endif
