@@ -143,8 +143,12 @@ bool CreatePath(const wchar *Path,bool SkipLastName)
 
 bool CreatePath(const char *Path,const wchar *PathW,bool SkipLastName)
 {
+#ifdef _WIN_ALL
+  // If we are in Windows, let's try Unicode path first. In Unix we do not
+  // need it (Unix MakeDir will fails with Unicode only name).
   if (PathW!=NULL && *PathW!=0)
     return(CreatePath(PathW,SkipLastName));
+#endif
   if (Path!=NULL && *Path!=0)
     return(CreatePath(Path,SkipLastName));
   return(false);
@@ -452,7 +456,12 @@ char *MkTemp(char *Name)
   size_t Length=strlen(Name);
   if (Length<=6)
     return(NULL);
-  int Random=clock();
+
+  // We need some kind of random start point for first temporary name.
+  RarTime CurTime;
+  CurTime.SetCurrentTime();
+  int Random=(int)CurTime.GetRaw();
+
   for (int Attempt=0;;Attempt++)
   {
     sprintf(Name+Length-6,"%06u",(Random+Attempt)%1000000);
@@ -473,7 +482,12 @@ wchar *MkTemp(wchar *Name)
   size_t Length=wcslen(Name);
   if (Length<=6)
     return(NULL);
-  uint Random=clock();
+
+  // We need some kind of random start point for first temporary name.
+  RarTime CurTime;
+  CurTime.SetCurrentTime();
+  int Random=(int)CurTime.GetRaw();
+
   for (uint Attempt=0;;Attempt++)
   {
     sprintfw(Name+Length-6,7,L"%06u",(Random+Attempt)%1000000);
